httpHeader class final

An HTTP header key.

Annotations
  • @Target.new({TargetKind.parameter})

Constructors

httpHeader([String? name])
An HTTP header key.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String?
The name of the HTTP header.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited