httpQuery class final

An HTTP query parameter key.

Annotations
  • @Target.new({TargetKind.parameter})

Constructors

httpQuery([String? name])
An HTTP query parameter key.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String?
The name of the HTTP query parameter.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited